/**
 * JASMINe
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JasmineEventManager.java 6494 2010-05-24 09:38:44Z renaultgu $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.common;

import java.util.ArrayList;
import java.util.List;

import org.ow2.jasmine.monitoring.eos.common.jms.event.JasmineMessageEvent;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * Events Manager. This class manages all the events from the JMS queue. Only
 * one instance of the manager must exist.
 *
 * @author Guillaume Renault
 */
public class JasmineEventManager implements EventManager<JasmineMessageEvent> {

    /**
     * Generated serialVersionUID.
     */
    private static final long serialVersionUID = 8808214442638812479L;

    /**
     * Logger.
     */
    private Log logger = LogFactory.getLog(this.getClass());

    /**
     * list of waiting events.
     */
    private List<JasmineMessageEvent> events = null;

    /**
     * Constructor of the manager. Initialize the list.
     */
    public JasmineEventManager() {
        this.events = new ArrayList<JasmineMessageEvent>();
    }

    /**
     * Add an event in the list.
     *
     * @param event the event to add.
     */
    public void add(final JasmineMessageEvent event) {
        this.logger.debug("Added event: {0}", event);

        synchronized (this.events) {
            this.events.add(event);
        }
    }

    /**
     * Get the entire queue of waiting events.
     *
     * @return the queue of events.
     */
    public List<JasmineMessageEvent> getAll() {
        this.logger.debug("Getting all events");

        synchronized (this.events) {
            List<JasmineMessageEvent> l = new ArrayList<JasmineMessageEvent>();
            l.addAll(this.events);
            this.events.removeAll(this.events);
            return l;
        }
    }
}
